aboutsummaryrefslogtreecommitdiff
path: root/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/SignatureType.java
diff options
context:
space:
mode:
Diffstat (limited to 'moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/SignatureType.java')
-rw-r--r--moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/SignatureType.java74
1 files changed, 37 insertions, 37 deletions
diff --git a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/SignatureType.java b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/SignatureType.java
index 70dc7b0..7e85412 100644
--- a/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/SignatureType.java
+++ b/moaSig/moa-asic/src/generated/java/at/gv/egiz/asic/SignatureType.java
@@ -1,8 +1,8 @@
//
-// This file was generated by the JavaTM Architecture for XML Binding(JAXB) Reference Implementation, v2.2.4
-// See <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a>
-// Any modifications to this file will be lost upon recompilation of the source schema.
-// Generated on: 2016.06.16 at 02:42:50 PM CEST
+// Diese Datei wurde mit der Eclipse Implementation of JAXB, v3.0.2 generiert
+// Siehe https://eclipse-ee4j.github.io/jaxb-ri
+// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren.
+// Generiert: 2021.12.14 um 08:52:42 PM CET
//
@@ -10,36 +10,36 @@ package at.gv.egiz.asic;
import java.util.ArrayList;
import java.util.List;
-import javax.xml.bind.annotation.XmlAccessType;
-import javax.xml.bind.annotation.XmlAccessorType;
-import javax.xml.bind.annotation.XmlAttribute;
-import javax.xml.bind.annotation.XmlElement;
-import javax.xml.bind.annotation.XmlID;
-import javax.xml.bind.annotation.XmlSchemaType;
-import javax.xml.bind.annotation.XmlType;
-import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
-import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
+import jakarta.xml.bind.annotation.XmlAccessType;
+import jakarta.xml.bind.annotation.XmlAccessorType;
+import jakarta.xml.bind.annotation.XmlAttribute;
+import jakarta.xml.bind.annotation.XmlElement;
+import jakarta.xml.bind.annotation.XmlID;
+import jakarta.xml.bind.annotation.XmlSchemaType;
+import jakarta.xml.bind.annotation.XmlType;
+import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
+import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
/**
- * <p>Java class for SignatureType complex type.
+ * <p>Java-Klasse für SignatureType complex type.
*
- * <p>The following schema fragment specifies the expected content contained within this class.
+ * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
*
* <pre>
- * &lt;complexType name="SignatureType">
- * &lt;complexContent>
- * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
- * &lt;sequence>
- * &lt;element ref="{http://www.w3.org/2000/09/xmldsig#}SignedInfo"/>
- * &lt;element ref="{http://www.w3.org/2000/09/xmldsig#}SignatureValue"/>
- * &lt;element ref="{http://www.w3.org/2000/09/xmldsig#}KeyInfo" minOccurs="0"/>
- * &lt;element ref="{http://www.w3.org/2000/09/xmldsig#}Object" maxOccurs="unbounded" minOccurs="0"/>
- * &lt;/sequence>
- * &lt;attribute name="Id" type="{http://www.w3.org/2001/XMLSchema}ID" />
- * &lt;/restriction>
- * &lt;/complexContent>
- * &lt;/complexType>
+ * &lt;complexType name="SignatureType"&gt;
+ * &lt;complexContent&gt;
+ * &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
+ * &lt;sequence&gt;
+ * &lt;element ref="{http://www.w3.org/2000/09/xmldsig#}SignedInfo"/&gt;
+ * &lt;element ref="{http://www.w3.org/2000/09/xmldsig#}SignatureValue"/&gt;
+ * &lt;element ref="{http://www.w3.org/2000/09/xmldsig#}KeyInfo" minOccurs="0"/&gt;
+ * &lt;element ref="{http://www.w3.org/2000/09/xmldsig#}Object" maxOccurs="unbounded" minOccurs="0"/&gt;
+ * &lt;/sequence&gt;
+ * &lt;attribute name="Id" type="{http://www.w3.org/2001/XMLSchema}ID" /&gt;
+ * &lt;/restriction&gt;
+ * &lt;/complexContent&gt;
+ * &lt;/complexType&gt;
* </pre>
*
*
@@ -68,7 +68,7 @@ public class SignatureType {
protected String id;
/**
- * Gets the value of the signedInfo property.
+ * Ruft den Wert der signedInfo-Eigenschaft ab.
*
* @return
* possible object is
@@ -80,7 +80,7 @@ public class SignatureType {
}
/**
- * Sets the value of the signedInfo property.
+ * Legt den Wert der signedInfo-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -92,7 +92,7 @@ public class SignatureType {
}
/**
- * Gets the value of the signatureValue property.
+ * Ruft den Wert der signatureValue-Eigenschaft ab.
*
* @return
* possible object is
@@ -104,7 +104,7 @@ public class SignatureType {
}
/**
- * Sets the value of the signatureValue property.
+ * Legt den Wert der signatureValue-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -116,7 +116,7 @@ public class SignatureType {
}
/**
- * Gets the value of the keyInfo property.
+ * Ruft den Wert der keyInfo-Eigenschaft ab.
*
* @return
* possible object is
@@ -128,7 +128,7 @@ public class SignatureType {
}
/**
- * Sets the value of the keyInfo property.
+ * Legt den Wert der keyInfo-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -145,7 +145,7 @@ public class SignatureType {
* <p>
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
* returned list will be present inside the JAXB object.
* This is why there is not a <CODE>set</CODE> method for the object property.
*
* <p>
@@ -169,7 +169,7 @@ public class SignatureType {
}
/**
- * Gets the value of the id property.
+ * Ruft den Wert der id-Eigenschaft ab.
*
* @return
* possible object is
@@ -181,7 +181,7 @@ public class SignatureType {
}
/**
- * Sets the value of the id property.
+ * Legt den Wert der id-Eigenschaft fest.
*
* @param value
* allowed object is
@@ -145,7 +145,7 @@ public class SignatureType {
* This accessor method returns a reference to the live list,
* not a snapshot. Therefore any modification you make to the
- * returned list will be present inside the JAXB object.
+ * returned list will be present inside the Jakarta XML Binding object.
* This is why there is not a <CODE>set</CODE> method for the object property.
*